WtFadeIn class

Fades child in from transparent.

Inheritance
Available extensions

Constructors

WtFadeIn({Key? key, required Widget child, Duration? duration, Duration delay = Duration.zero, Curve? curve})
Fades child into view.
const

Properties

child → Widget
The widget to fade in.
final
curve → Curve?
See WtAnimate.curve.
final
delay → Duration
See WtAnimate.delay.
final
duration → Duration?
See WtAnimate.duration.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
wtFadeIn({Duration? duration, Duration delay = Duration.zero, Curve? curve}) → Widget

Available on Widget, provided by the WtAnimateX extension

Fades this widget in. See WtFadeIn.
wtScaleIn({double scaleFrom = 0.9, Duration? duration, Duration delay = Duration.zero, Curve? curve, bool fade = true}) → Widget

Available on Widget, provided by the WtAnimateX extension

Scales this widget in. See WtScaleIn.
wtSlideIn({WtDir from = WtDir.bottom, double distance = 0.15, Duration? duration, Duration delay = Duration.zero, Curve? curve, bool fade = true}) → Widget

Available on Widget, provided by the WtAnimateX extension

Slides this widget in from from (default bottom). See WtSlideIn.
wtSlideUp({Duration? duration, Duration delay = Duration.zero, Curve? curve}) → Widget

Available on Widget, provided by the WtAnimateX extension

Slides this widget up from below — shorthand for wtSlideIn(from: bottom).
wtStagger({required int index, Duration interval = const Duration(milliseconds: 60), WtDir from = WtDir.bottom, Duration? duration, Curve? curve}) → Widget

Available on Widget, provided by the WtAnimateX extension

Staggered entrance for item index in a list: delays the animation by interval * index. Use inside ListView.builder item builders.

Operators

operator ==(Object other) → bool
The equality operator.
inherited