WtRoute class

A single route: a path pattern (supports :param segments) and the builder that creates its controller.

Constructors

WtRoute({required String path, required WtRouteBuilder builder, WtTransition? transition})
Creates a route binding path to builder, optionally with its own transition.
const

Properties

builder → WtRouteBuilder
Creates the controller for this route.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
Path pattern, e.g. /ad/:id. :name segments are dynamic.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transition → WtTransition?
Page transition for this route. When null, the router uses WtConfig.pageTransition (which itself defaults to WtTransition.platform).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited