WtSecurity class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
String encoded, String secretKey) → String? -
encode(
String data, String secretKey) → String -
generateToken(
{int length = 32}) → String -
hashWithKey(
String data, String secretKey) → String -
isValidEmail(
String email) → bool -
isValidInput(
String input) → bool -
sanitize(
Map< String, dynamic> data) → Map<String, dynamic>