WtController class abstract

Constructors

WtController(RouteSettings settings)

Properties

hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings
final

Methods

back(BuildContext context) → void
loadModel<T>(WtModel<T> model) Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redirect(BuildContext context, String route, {Object? args}) → void
render(BuildContext context) Widget
toString() String
A string representation of this object.
inherited
view(BuildContext context) WtView

Operators

operator ==(Object other) bool
The equality operator.
inherited