WtAsyncView<T> class abstract

Inheritance

Constructors

WtAsyncView()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setterinherited

Methods

assign(String key, dynamic value) → void
inherited
build(BuildContext context) Widget
override
buildData(BuildContext context, T data) Widget
empty({String message = 'No data found'}) Widget
inherited
error(String message) Widget
inherited
get<T>(String key) → T?
inherited
loadData() Future<T>
loading() Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaffold({required BuildContext context, required Widget body, Widget? floatingActionButton, List<Widget>? actions, Widget? drawer, bool showAppBar = true}) Widget
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited