WtRoute class
A single route: a path pattern (supports :param segments) and the
builder that creates its controller.
Constructors
- WtRoute({required String path, required WtRouteBuilder builder})
-
Creates a route binding
pathtobuilder.const
Properties
- builder → WtRouteBuilder
-
Creates the controller for this route.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
Path pattern, e.g.
/ad/:id.:namesegments are dynamic.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited