WtRouter class

Constructors

WtRouter({required List<WtRoute> routes, String initialRoute = '/', Widget notFoundPage(BuildContext, RouteSettings)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialRoute String
final
notFoundPage Widget Function(BuildContext, RouteSettings)?
final
routes List<WtRoute>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispatch(RouteSettings settings) Route?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getParams(String pattern, String path) Map<String, String>