WtHelper class

Constructors

WtHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

confirm(BuildContext context, {required String title, required String message, String confirmText = 'Confirm', String cancelText = 'Cancel'}) Future<bool>
currency(double amount, {String symbol = '\$', int decimals = 2}) String
flash(BuildContext context, String message, {bool isError = false}) → void
formatDate(DateTime date, {String format = 'yyyy-MM-dd'}) String
formatDateTime(DateTime date) String
formatNumber(num number) String
hideLoading(BuildContext context) → void
showLoading(BuildContext context) → void
slug(String text) String
timeAgo(DateTime date) String
truncate(String text, int maxLength, {String suffix = '...'}) String
ucFirst(String text) String