WtSession class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
destroy(
) → Future< void> -
get<
T> (String key) → T? -
getUser(
) → Map< String, dynamic> ? -
has(
String key) → bool -
init(
) → Future< void> -
isLoggedIn(
) → bool -
login(
Map< String, dynamic> userData) → Future<void> -
logout(
) → Future< void> -
remove(
String key) → Future< void> -
set(
String key, dynamic value) → Future< void>