WtView class abstract

Implementers

Constructors

WtView()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setter

Methods

assign(String key, dynamic value) → void
build(BuildContext context) Widget
empty({String message = 'No data found'}) Widget
error(String message) Widget
get<T>(String key) → T?
loading() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaffold({required BuildContext context, required Widget body, Widget? floatingActionButton, List<Widget>? actions, Widget? drawer, bool showAppBar = true}) Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited